@@ -1,6 +1,8 @@
 import functools
 from . import sql_support
 from .engine import Engine
+from .loader import Loader
+from typing import Collection, Iterable
 from .init_import import import_driver, get_engine
 from .log_support import logger, insert_log, save_log, do_sql_log, sql_log
 from .support import DBCtx, ConnectionCtx, Dict, MultiColumnsError, TransactionCtx, try_commit, DBError, DB_LOCK
@@ -156,7 +158,7 @@ def insert(table: str, **kwargs):
     return execute(sql, *args)
 
 
-def save(select_key: str, table: str, **kwargs):
+def save(select_key: str, table: str, **kwargs) -> int:
     """
     Insert data into table, return primary key.
 
@@ -359,6 +361,95 @@ def batch_execute(sql: str, *args):
             cursor.close()
 
 
+def load(sql: str, *args, **kwargs) -> Loader:
+    """
+    Execute select SQL and save a csv
+
+    sqlexec.load('select id, name, age from person WHERE name=:name', name='张三')
+
+    :param sql: SELECT * FROM person WHERE name=? and age=? limit 1 -->  args: ('张三', 20)
+                SELECT * FROM person WHERE name=:name and age=:age limit 1 --> kwargs: {'name': '张三', 'age': 20}
+    :return: Loader
+    """
+    sql, args = try_mapping('sqlexec.csv', sql, *args, **kwargs)
+    return do_load(sql, *args)
+
+
+def do_load(sql: str, *args) -> Loader:
+    """
+    Execute select SQL and save a csv
+
+    sqlexec.do_load('select id, name, age from person WHERE name = ?', '张三')
+
+    :param sql: SELECT * FROM person WHERE name=? and age=? limit 1 -->  args: ('张三', 20)
+    :return: Loader
+    """
+    result, description = _select(sql, *args)
+    return Loader(result, description)
+
+
+def insert_from_csv(file_name: str, table: str, delimiter=',', header=True, columns: Collection[str] = None, encoding='utf-8'):
+    """
+    sqlexec.insert_from_csv('test.csv', 'person')
+    """
+    import csv
+    sql = None
+    if columns and len(columns) > 0:
+        sql = sql_support.insert_sql(table.strip(), columns)
+    elif not header:
+        raise ValueError("Expected one of 'header' and 'columns'.")
+
+    with open(file_name, newline='', encoding=encoding) as f:
+        lines = csv.reader(f, delimiter=delimiter)
+        lines = [line for line in lines]
+
+    if len(lines) == 0:
+        return 0
+
+    if header:
+        if len(lines) == 1:
+            return 0
+
+        if sql is None:
+            sql = sql_support.insert_sql(table.strip(), lines[0])
+        lines = lines[1:]
+
+    return batch_execute(sql, lines)
+
+
+def insert_from_df(df, table: str, columns: Collection[str] = None):
+    """
+    sqlexec.insert_from_df(df, 'person')
+    """
+    columns = columns if columns and len(columns) > 0 else df.columns.tolist()
+    sql = sql_support.insert_sql(table.strip(), columns)
+    return batch_execute(sql, df.values.tolist())
+
+
+def insert_from_json(file_name: str, table: str, encoding='utf-8'):
+    """
+    sqlexec.insert_from_json('test.json', 'person')
+
+    many rows json file example:
+    [{"id": 1, "name": "张三", "age": 55}, ...]
+
+    one row json file example:
+    {"id": 1, "name": "张三", "age": 55}
+    """
+    import json
+
+    with open(file_name, encoding=encoding) as f:
+        data = json.load(f)
+
+    if isinstance(data, dict):
+        return insert(table, **data)
+    elif isinstance(data, Iterable):
+        return batch_insert(table, data)
+    else:
+        logger.info("Exec func 'sqlexec.%s' \n\t Table: '%s' insert 0 rows." % ('insert_from_json', table ))
+        return 0
+
+
 def get_connection():
     global _DB_CTX
     _DB_CTX.try_init()
