@@ -1,10 +1,73 @@
 from . import exec
+from .loader import Loader
 
 
-def sql(sql: str) :
-    sql = sql.strip()
-    assert sql, "Parameter 'sql' must not be none"
-    return SqlExec(sql, exec)
+class Param:
+
+    def __init__(self, sqlExec, *args, **kwargs):
+        self.sqlExec = sqlExec
+        self.args = args
+        self.kwargs = kwargs
+
+    def execute(self) -> int:
+        """
+        sqlexec.sql('INSERT INTO person(name, age) VALUES(?, ?)').param('张三', 18).execute()
+        """
+        return self.sqlExec.execute(*self.args, **self.kwargs)
+
+    def save(self, select_key: str):
+        """
+        sqlexec.sql('INSERT INTO person(name, age) VALUES(?, ?)').param('张三', 18).save('SELECT LAST_INSERT_ID()')
+        """
+        return self.sqlExec.save(select_key, *self.args, **self.kwargs)
+
+    def get(self):
+        """
+        sqlexec.sql('SELECT count(1) FROM person WHERE name=? and age=? limit 1').param('张三', 18).get()
+        """
+        return self.sqlExec.get(*self.args, **self.kwargs)
+
+    def select(self):
+        """
+        sqlexec.sql('SELECT * FROM person WHERE name=? and age=?').param('张三', 18).select()
+        """
+        return self.sqlExec.select(*self.args, **self.kwargs)
+
+    def select_one(self):
+        """
+        sqlexec.sql('SELECT * FROM person WHERE name=? and age=? limit 1').param('张三', 18).select_one()
+        """
+        return self.sqlExec.select_one(*self.args, **self.kwargs)
+
+    def query(self):
+        """
+        sqlexec.sql('SELECT * FROM person WHERE name=? and age=?').param('张三', 18).query()
+        """
+        return self.sqlExec.query(*self.args, **self.kwargs)
+
+    def query_one(self):
+        """
+        sqlexec.sql('SELECT * FROM person WHERE name=? and age=? limit 1').param('张三', 18).query_one()
+        """
+        return self.sqlExec.query_one(*self.args, **self.kwargs)
+
+    def csv(self, file_name: str, delimiter=',', header=True, encoding='utf-8'):
+        """
+        sqlexec.sql('SELECT * FROM person WHERE name=? and age=?').param('张三', 18).csv('test.csv')
+        """
+        self.sqlExec.load(*self.args, **self.kwargs).csv(file_name, delimiter, header, encoding)
+
+    def df(self):
+        """
+        sqlexec.sql('SELECT * FROM person WHERE name=? and age=?').param('张三', 18).df()
+        """
+        return self.sqlExec.load(*self.args, **self.kwargs).df()
+
+    def json(self, file_name: str, encoding='utf-8'):
+        """
+        sqlexec.sql('SELECT * FROM person WHERE name=? and age=?').param('张三', 18).json('test.json')
+        """
+        self.sqlExec.load(*self.args, **self.kwargs).json(file_name, encoding)
 
 
 class SqlExec:
@@ -13,7 +76,7 @@ class SqlExec:
         self.sql = sql
         self.executor = executor
 
-    def execute(self, *args, **kwargs):
+    def execute(self, *args, **kwargs) -> int:
         """
         Execute sql return effect rowcount
 
@@ -147,3 +210,32 @@ class SqlExec:
         :return: Effect rowcount
         """
         return self.executor.batch_execute(self.sql, *args)
+
+    def load(self, *args, **kwargs) -> Loader:
+        """
+        sqlexec.sql('select id, name, age from person WHERE name = :name').load(name='张三')
+        sql: SELECT * FROM person WHERE name=? and age=?  -->  args: ('张三', 20)
+             SELECT * FROM person WHERE name = :name and age=:age  -->  kwargs: ('张三', 20) --> kwargs: {'name': '张三', 'age': 20}
+        """
+        return self.executor.load(self.sql, *args, **kwargs)
+
+    def do_load(self, *args) -> Loader:
+        """
+        sqlexec.sql('select id, name, age from person WHERE name = ?').do_load('张三')
+        sql: SELECT * FROM person WHERE name=? and age=?  -->  args: ('张三', 20)
+        """
+        return self.executor.do_load(self.sql, *args)
+
+    def param(self, *args, **kwargs) -> Param:
+        """
+        sqlexec.sql('select id, name, age from person WHERE name = :name').param(name='张三')
+        sql: SELECT * FROM person WHERE name=? and age=?  -->  args: ('张三', 20)
+             SELECT * FROM person WHERE name = :name and age=:age  -->  kwargs: ('张三', 20) --> kwargs: {'name': '张三', 'age': 20}
+        """
+        return Param(self, *args, **kwargs)
+
+
+def sql(sql_text: str) -> SqlExec:
+    sql_text = sql_text.strip()
+    assert sql_text, "Parameter 'sql' must not be none"
+    return SqlExec(sql_text, exec)
