@@ -1,19 +1,23 @@
 import re
 from .engine import Engine
-from typing import Sequence
 from .support import DBError
+from typing import Collection
 from functools import lru_cache
 from .constant import CACHE_SIZE, NAMED_REGEX, LIMIT_1
 
+
+def insert_sql(table: str, cols: Collection[str]):
+    cols = cols if isinstance(cols, tuple) else tuple(cols)
+    return Engine.create_insert_sql_intf(table, cols)
+
 def insert_sql_args(table: str, **kwargs):
     cols, args = zip(*kwargs.items())
     sql = Engine.create_insert_sql_intf(table, cols)
     return sql, args
 
 
-
 def get_batch_args(*args):
-    return args[0] if isinstance(args, tuple) and len(args) == 1 and isinstance(args[0], Sequence) else args
+    return args[0] if isinstance(args, tuple) and len(args) == 1 and isinstance(args[0], Collection) else args
 
 
 def batch_insert_sql_args(table: str, *args):
